<?php
// THEME OPTIONS ------------------------------------------------------------------------

	//theme support
	if ( !isset( $content_width ) ) $content_width = 1042; // define width in pixels
	add_theme_support( 'post-thumbnails' ); // theme supports post thumbnails
	add_theme_support( 'automatic-feed-links' ); // theme supports automatic feed links

	// background colors (pre/post 3.4)
	if( magomra_is_wp_version( '3.4' ) ) 
		add_theme_support( 'custom-background', array( 'default-color' => 'ddd' ) ); // not used until 3.4
	else 
		add_custom_background( 'magomra_background_depreciated' ); // depreciated in 3.4

	// theme options
	require_once( get_template_directory() . '/options/theme-options.php' );


// FILTER FUNCTIONS ------------------------------------------------------------------------

// checks is WP is at least a certain version
function magomra_is_wp_version( $is_ver ) {
	$wp_ver = explode( '.', get_bloginfo( 'version' ) );
	$is_ver = explode( '.', $is_ver );
	for( $i=0; $i<=4; $i++ )
		if( !isset( $wp_ver[$i] ) ) array_push( $wp_ver, 0 );

	foreach( $is_ver as $i => $is_val )
		if( $wp_ver[$i] < $is_val ) return false;
	return true;
}

// changes the background color (method depreciated in version 3.4)
function magomra_background_depreciated() {
	$options = get_option( 'magomra-theme-options', magomra_default_options() ); // check theme options
	echo '<style type="text/css">html { background-color: ' . $options['bg_color'] . '; }</style>
	';
}

// filter function for the default searchform (mainly a safe way to optionally remove the role attribute)
function magomra_searchform_filter( $form ) {
	$options = get_option( 'magomra-theme-options', magomra_default_options() ); // check theme options
	if( isset( $options['w3c_comply'] ) )
		return str_replace( ' role="search"', '', $form );
	else
		return $form;
}

// filter function to add breadcrumbs to <title>
function magomra_title_filter( $title, $sep, $seplocation ) {
	$ssep = ' ' . $sep . ' '; // $ssep = padded $sep

	// get special index page type (if any)
	if( !is_single() ) { 
		if( is_category() ) $pre = $ssep . 'Category';
		elseif( is_tag() ) $pre = $ssep . 'Tag';
		elseif( is_author() ) $pre = $ssep . 'Author';
		elseif( is_year() || is_month() || is_day() ) $pre = $ssep . 'Archives';
	}
	else $pre = '';

	// get the page number
	if( get_query_var( 'paged' ) ) $num = $ssep . 'page ' . get_query_var( 'paged' ); // on index
	elseif( get_query_var( 'page' ) ) $num = $ssep . 'page ' . get_query_var( 'page' ); // on single
	else $num = '';

	// concoct and return title
	return get_bloginfo( 'name' ) . $pre . $title . $num;
}

// filter function to add classes to blogroll items
function magomra_blogroll_filter( $bookmarks, $classes='blogroll-item' ) {
	if( is_array( $classes ) ) $classes = implode( ' ', $classes ); // implode if passed as array
	return preg_replace('/<li>/','<li class="' . $classes . '">', $bookmarks );
}

// filter function to pluralize nouns
function magomra_plural( $count, $noun, $echo = TRUE, $irregular = FALSE ) {

	// ends with s or irregular suffix
	if( !$irregular ) $suffix = 's';
	else $suffix = $irregular;
	
	// singular or plural
	if( $count > 1 ) $return = $count . ' ' . $noun . $suffix;
	else $return = '1 ' . $noun;
	
	// return or echo
	if( $echo ) echo $return; 
	else return $return;
}


// PRINT THEME COMPONENTS ------------------------------------------------------------------------

// displays if a special index page is being viewed
function magomra_special_index( $post ) { 

	if( !is_single( $post ) ) : // skip if single

	// category
	if( is_category( $post ) ) { 
		$title = 'Category';
		$item =  single_cat_title( '', false );
		$message = 'You are now browsing all items filed in the "%8$s" category.';
	}

	// tag
	elseif( is_tag( $post ) ) { 
		$title = 'Tag'; 
		$item = single_tag_title('', false );
		$message = 'You are now browsing all items tagged with "%8$s."';
	}

	// author
	elseif( is_author() ) {
		$title = 'Author'; 
		$item = get_the_author();
		$message = 'You are now browsing all items authored by %8$s.'; 
	}
	
	// archives (month or day)
	elseif( is_month() || is_day() ) {
		$title = 'Archives'; 
		$item = substr( single_month_title(', ', false ), 2 );
		$message = 'You are now browsing the archives for items from %8$s.';
	}

	// archive (year)
	elseif( is_year() ) {
		$title = 'Archives'; 
		$item = get_the_date( 'Y');
		$message = 'You are now browsing the archives for posts from the year %8$s.'; 
	}
	
	// search
	elseif( is_search() ) {
		$title = 'Search'; 
		$item = get_search_query();
		$message= 'You are now browsing our search results for "%8$s."';
	}

	else return;
	
	// print content
	printf( '%1$s%2$s<li class="%6$s">%1$s%2$s%2$s<h2 class="%7$s">%3$s%4$s%5$s</h2>%2$s%2$s<p>' . $message . '</p>%1$s</li>',
		"\n", // line break
		"\t", // tab
		'&laquo; ', // before title
		$title, // title
		' Index', // after title
		'widget magomra-index-type-widget', // widget classes
		'widget-title magomra-index-type', // title classes
		$item
	); 

endif; // /!is_single()
return;
}

// NAVIGATION ------------------------------------------------------------------------

// prints the index navigation links (if exist)
function magomra_index_nav( $next_text='&laquo; Older', $prev_text='Newer &raquo;' ) {
	$next_posts = get_next_posts_link( $next_text );
	$prev_posts = get_previous_posts_link( $prev_text );
	if( !empty( $next_posts ) )
		echo '<div class="post-navigation-next">' . $next_posts . '</div>';
	if( !empty( $prev_posts ) ) 
		echo '<div class="post-navigation-prev">' . $prev_posts  . '</div>'; 
}

// prints the navigation menus
function magomra_nav_menu( $menu_id ) {
	// main navigation menu
	if( $menu_id === 0 || $menu_id == 'primary' )
	$args = array(
		'theme_location'	=> 'navigation_menu_primary',
		'container'			=> 'div',
		'container_id'		=> 'top-navigation-primary',
		'conatiner_class'	=> 'top-navigation',
		'menu_class'		=> 'menu main-menu menu-depth-0 menu-even', 
		'echo'				=> true,
		'fallback_cb'		=> 'magomra_nav_fallback', // show skinned wp_list_pages by default
		'items_wrap'		=> '<ul id="%1$s" class="%2$s">%3$s</ul>',
		'depth'				=> 10, 
		'walker'			=> new magomra_walker_nav_menu
	);

	// secondary navigation menu
	elseif( $menu_id === 1 || $menu_id == 'secondary' )
	$args = array(
		'theme_location'	=> 'navigation_menu_secondary',
		'container'			=> 'div',
		'container_id'		=> 'top-navigation-secondary',
		'conatiner_class'	=> 'top-navigation',
		'menu_class'		=> 'menu main-menu menu-depth-0 menu-even', 
		'echo'				=> true,
		'fallback_cb'		=> false, // not shown by default
		'items_wrap'		=> '<ul id="%1$s" class="%2$s">%3$s</ul>',
		'depth'				=> 2, 
		'walker'			=> new magomra_walker_nav_menu
	);
	
	// print menu
	wp_nav_menu( $args );
}

// registers the navigation menus
function magomra_register_menus(){
	register_nav_menu( 'navigation_menu_primary', 'Main Top Navigation Menu' );
	register_nav_menu( 'navigation_menu_secondary', 'Secondary Top Navigation Menu' );
}

// primary nav_menu fallback function
function magomra_nav_fallback() {
	$args = array( 'echo'=>0, 'title_li'=>'', 'depth'=>10, 'walker' => new magomra_walker_page );
	$pages = '
	<div id="top-navigation-primary" class="top-navigation">
		<ul class="menu main-menu menu-depth-0 menu-even">' . 
			wp_list_pages( $args ) .
		'</ul>
	</div>';
	echo $pages;
}

// walker function for wp_list_pages
class magomra_walker_page extends Walker_Page {
	
	function start_lvl( &$output, $depth ) {
		// depth dependent classes
		$indent = ( $depth > 0  ? str_repeat( "\t", $depth ) : '' ); // code indent
		$display_depth = ( $depth + 1 ); // because it counts the first submenu as 0
		$classes = array(
			'sub-menu',
			'menu-depth-' . $display_depth,
			( $display_depth % 2  ? 'menu-odd' : 'menu-even' ),
			( $display_depth >= 2 ? 'sub-sub-menu' : '' )
		);
		
		$class_names = implode( ' ', $classes );
		
		// build html
		$output .= "\n" . $indent . '<ul class="' . $class_names . '">' . "\n";
    }
	
	function end_lvl ( &$output, $depth ) {
		$output .= '</ul>' . "\n";
	}
	
	function start_el( &$output, $page, $depth, $args, $current_page ) {
		$indent = ( $depth ? str_repeat( "\t", $depth ) : '' ); // code indent
		extract( $args, EXTR_SKIP ); // extract args
		
		// css classes
		$classes = array(
			'menu-item', 
			'menu-item-'. $page->ID,
			'menu-item-depth-' . $depth, 
			( $depth == 0 ? 'main-menu-item' : 'sub-menu-item' ),
			( $depth >=2 ? 'sub-sub-menu-item' : '' ),
			( $depth % 2 ? 'menu-item-odd' : 'menu-item-even' )
		);
		
		$link_classes = array(
			'menu-link',
			( $depth == 0 ? 'main-menu-link' : 'sub-menu-link' )
		);
		
		// build html
		$class_names = esc_attr( implode( ' ', apply_filters( 'page_css_class', $classes, $page ) ) );
		$link_class_names = implode( ' ', $link_classes );
	    $output .= sprintf( 
			'%1$s<li class="%2$s"><a href="%3$s" title="%4$s" class="%7$s">%5$s%4$s%6$s</a>', 
			$indent, // 1
			$class_names, // 2
			get_page_link( $page->ID ), // 3
			esc_attr( apply_filters( 'the_title', $page->post_title ) ), // 4
			$link_before, // 5
			$link_after, // 6
			$link_class_names //7
		);
	}
}

// custom Nav_Menu_Walker
class magomra_walker_nav_menu extends Walker_Nav_Menu {
    
	// add classes to ul sub-menus
	function start_lvl( &$output, $depth ) {
		// depth dependent classes
		$indent = ( $depth > 0  ? str_repeat( "\t", $depth ) : '' ); // code indent
		$display_depth = ( $depth + 1); // because it counts the first submenu as 0
		$classes = array(
			'sub-menu',
			( $display_depth % 2  ? 'menu-odd' : 'menu-even' ),
			( $display_depth >=2 ? 'sub-sub-menu' : '' ),
			'menu-depth-' . $display_depth
			);
		$class_names = implode( ' ', $classes );
		
		// build html
		$output .= "\n" . $indent . '<ul class="' . $class_names . '">' . "\n";
    }

	// add main/sub classes to li's and links
	 function start_el( &$output, $item, $depth, $args ) {
		global $wp_query;
		$indent = ( $depth > 0 ? str_repeat( "\t", $depth ) : '' ); // code indent
		
		// depth dependent classes
		$depth_classes = array(
			( $depth == 0 ? 'main-menu-item' : 'sub-menu-item' ),
			( $depth >=2 ? 'sub-sub-menu-item' : '' ),
			( $depth % 2 ? 'menu-item-odd' : 'menu-item-even' ),
			'menu-item-depth-' . $depth
		);
		$depth_class_names = esc_attr( implode( ' ', $depth_classes ) );

		// passed classes
		$classes = empty( $item->classes ) ? array() : (array) $item->classes;
		$class_names = esc_attr( implode( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item ) ) );

		// build html
		$output .= $indent . '<li id="nav-menu-item-'. $item->ID . '" class="' . $depth_class_names . ' ' . $class_names . '">';

		// link attributes
		$attributes  = ! empty( $item->attr_title ) ? ' title="'  . esc_attr( $item->attr_title ) .'"' : '';
		$attributes .= ! empty( $item->target )     ? ' target="' . esc_attr( $item->target     ) .'"' : '';
		$attributes .= ! empty( $item->xfn )        ? ' rel="'    . esc_attr( $item->xfn        ) .'"' : '';
		$attributes .= ! empty( $item->url )        ? ' href="'   . esc_attr( $item->url        ) .'"' : '';
		$attributes .= ' class="menu-link ' . ( $depth > 0 ? 'sub-menu-link' : 'main-menu-link' ) . '"';
		
		$item_output = sprintf( '%1$s<a%2$s>%3$s%4$s%5$s</a>%6$s', 
			$args->before,
			$attributes,
			$args->link_before,
			apply_filters( 'the_title', $item->title, $item->ID ),
			$args->link_after,
			$args->after
		);

		// build html
		$output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args );
	}
}



// COMMENTS ------------------------------------------------------------------------

// Custom callback to list comments in the your-theme style
function magomra_custom_comments( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
    $GLOBALS['comment_depth'] = $depth;
?>

	<li id="comment-<?php comment_ID() ?>" <?php comment_class( 'response' ) ?>>
        <div class="comment-author response-author"><?php magomra_commenter_link() ?></div>
        <div class="comment-meta">
			<span class="comment-meta-span">
			<?php printf( 'Posted %1$s at %2$s | <a href="%3$s" title="Permalink to this comment">Permalink</a>',
		         get_comment_date(),
		         get_comment_time(),
		         '#comment-' . get_comment_ID() );
		         edit_comment_link( 'Edit', ' | <span class="edit-link">', '</span>'); ?>
			</span>
		</div>

<?php if( !$comment->comment_approved ) echo '<span class="unapproved">Your comment is awaiting moderation.'; ?>

		<div class="comment-content">
			<?php comment_text() ?>
        </div>
        
		<?php // echo the comment reply link
		if( $args['type'] == 'all' || get_comment_type() == 'comment' ) {
		     $extra_args = array(
				 'reply_text' => __( 'Reply', 'magomra-theme' ),
		         'login_text' => __( 'Log in to reply.', 'magomra-theme' ),
		         'depth' => $depth,
		         'before' => '<div class="comment-reply">',
		         'after' => '</div>'
			);
						 
			comment_reply_link( array_merge( $args, $extra_args ) );
		}
}

// Custom callback to list pings
function magomra_custom_pings( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment; 
?>
	
	<li id="comment-<?php comment_ID() ?>" <?php comment_class() ?>>
    	<div class="trackback-author">
			<?php printf( 'By %1$s on %2$s at %3$s',
				get_comment_author_link(),
				get_comment_date(),
				get_comment_time() );
				edit_comment_link( 'Edit', ' <span class="meta-sep">|</span> <span class="edit-link">', '</span>'
			); ?>
		</div>
		
<?php if ( !$comment->comment_approved ) echo '<span class="unapproved">Your trackback is awaiting moderation.'; ?>

		<div class="comment-content">
		     <?php comment_text() ?>
		 </div>
<?php 
}

// produces an avatar image with the hCard-compliant photo class
function magomra_commenter_link() {
	$commenter = get_comment_author_link();
	if( ereg( '<a[^>]* class=[^>]+>', $commenter ) )
		$commenter = ereg_replace( '(<a[^>]* class=[\'"]?)', '\\1url ' , $commenter );
	else		
		$commenter = ereg_replace( '(<a )/', '\\1class="url "' , $commenter );
	
    $avatar_email = get_comment_author_email();
    $avatar = str_replace( "class='avatar", "class='photo avatar", get_avatar( $avatar_email, 80 ) );
    echo $avatar . ' <span class="fn n">' . $commenter . '</span>';
}

// SIDEBAR ------------------------------------------------------------------------

// draws the default sidebar if no widgets are added
function magomra_default_sidebar() {
	
	// sidebar area args to pass
	$args = array( 
		'before_widget' => '<li id="%1$s" class="widget %2$s">',
		'after_widget'  => '</li>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>'
	);
	
	// widgets to add
	$widgets = array(
		array( 'widget' => 'WP_Widget_Search', 'instance' => '' ),
		array( 'widget' => 'WP_Widget_Meta', 'instance' => array( 'title' => 'Login' ) ),
		array( 'widget' => 'WP_Widget_Categories', 'instance' => array( 'hierarchical' => 1, 'count' => 1 ) ), 
		array( 'widget' => 'WP_Widget_Calendar', 'instance' => '' ),
		array( 'widget' => 'WP_Widget_Tag_Cloud', 'instance' => array( 'title' => 'Calendar' ) ),
		array( 'widget' => 'WP_Widget_Calendar', 'instance' => '' ),
		array( 'widget' => 'WP_Widget_Archives', 'instance' => array( 'dropdown' => 1 ) ),
		array( 'widget' => 'WP_Widget_Pages', 'instance' => '' ),
		array( 'widget' => 'WP_Widget_Recent_Posts', 'instance' => array( 'number' => 5 ) ),
		array( 'widget' => 'WP_Widget_Recent_Comments', 'instance' => array( 'number' => 5 ) )
	);

	foreach( $widgets as $widget )
		the_widget( $widget['widget'], $widget['instance'], $args );
}

// registers the dynamic sidebar
function magomra_register_sidebar(){
	// arguments
	$args = array(
		'name'          => 'Main Sidebar',
		'id'			=> 'main_sidebar',
		'description'   => 'The main sidebar.',
		'before_widget' => '<li id="%1$s" class="widget %2$s">',
		'after_widget'  => '</li>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>' 
	);
	
	register_sidebar( $args );
}

// HOOKS AND FILTERS
add_filter( 'get_search_form', 'magomra_searchform_filter' );
add_action( 'widgets_init', 'magomra_register_sidebar' );
add_action( 'after_setup_theme', 'magomra_register_menus' );
add_filter( 'wp_title', 'magomra_title_filter', 10, 3 );
add_filter('wp_list_bookmarks', 'magomra_blogroll_filter', 10, 1);

?>